@@ -5,6 +5,8 @@ use strict;
 use warnings;
 use utf8;
 
+=encoding utf8
+
 =head1 NAME
 
 App::RetroPAN - Makes a historic minicpan ⏳
@@ -24,9 +26,13 @@ satisfy your modules' dependencies.
 
 =over
 
-=item L<retropan>
+=item *
 
-=item L<OrePAN2>
+L<retropan>
+
+=item *
+
+L<OrePAN2>
 
 =back
 
@@ -49,7 +55,7 @@ use OrePAN2::Indexer;
 
 use Cpanel::JSON::XS qw/ encode_json decode_json /;
 
-our $VERSION = '0.01_01';
+our $VERSION = '0.01_02';
 
 my $ua = LWP::UserAgent->new( keep_alive => 2, agent => "retropan/$VERSION" );
 
